@@ -17,16 +17,10 @@ MBLENGTH = {
 
 FIELD_TYPE_VAR_STRING=253
 
-NULL_COLUMN = 251
 UNSIGNED_CHAR_COLUMN = 251
 UNSIGNED_SHORT_COLUMN = 252
 UNSIGNED_INT24_COLUMN = 253
 UNSIGNED_INT64_COLUMN = 254
-UNSIGNED_CHAR_LENGTH = 1
-UNSIGNED_SHORT_LENGTH = 2
-UNSIGNED_INT24_LENGTH = 3
-UNSIGNED_INT64_LENGTH = 8
-
 
 def unpack_uint16(n):
     if PYTHON3:
@@ -47,23 +41,6 @@ def unpack_uint32(n):
         return ord(n[0]) + (ord(n[1]) << 8) + \
             (ord(n[2]) << 16) + (ord(n[3]) << 24)
 
-def read_mysqlpacket(connection):
-    return _read_mysqlpacket(connection)
-
-def _read_mysqlpacket(connection):
-      packet = MysqlPacket(connection)
-      _errno, _data = packet.check_error()
-      if _errno:
-        raise_mysql_exception(_data)
-      return packet
-
-def read_fielddescriptorpacket(connection):
-      packet = FieldDescriptorPacket(connection)
-      _errno, _data = packet.check_error()
-      if _errno:
-        raise_mysql_exception(_data)
-      return packet
-
 
 class MysqlPacket(object):
     """Representation of a MySQL response packet.  Reads in the packet
@@ -74,13 +51,20 @@ class MysqlPacket(object):
         self.connection = connection
         self.__position = 0
         self.__recv_packet()
+        if PYTHON3:
+            is_error = self.__data[0] == 0xff
+        else:
+            is_error = self.__data[0] == b'\xff'
+        if is_error:
+            self.advance(1)  # field_count == error (we already know that)
+            errno = unpack_uint16(self._read(2))
+            raise_mysql_exception(self.__data)
 
     def __recv_from_socket(self, size):
         r = b''
         while size:
             recv_data = self.connection.socket.recv(size)
-            recieved = len(recv_data)
-            if recieved == 0:
+            if not recv_data:
                 break
             size -= len(recv_data)
             r += recv_data
@@ -92,9 +76,9 @@ class MysqlPacket(object):
         if len(packet_header) < 4:
             raise OperationalError(2013, "Lost connection to MySQL server during query")
 
-        bytes_to_read = unpack_uint24(packet_header[:3])
-        self.packet_number = ord(packet_header[3:])
+        bytes_to_read = unpack_uint24(packet_header)
         # TODO: check packet_num is correct (+1 from last packet)
+        # self.packet_number = ord(packet_header[3:])
   
         recv_data = self.__recv_from_socket(bytes_to_read)
         if len(recv_data) < bytes_to_read:
@@ -138,24 +122,6 @@ class MysqlPacket(object):
                         'Position=%s' % (length, new_position))
         self.__position = new_position
   
-    def rewind(self, position=0):
-        """Set the position of the data buffer cursor to 'position'."""
-        if position < 0 or position > self.__data_length:
-            raise Exception(
-                    "Invalid position to rewind cursor to: %s." % position)
-        self.__position = position
-  
-    def get_bytes(self, position, length=1):
-        """Get 'length' bytes starting at 'position'.
-  
-        Position is start of payload (first four packet header bytes are not
-        included) starting at index '0'.
-  
-        No error checking is done.  If requesting outside end of buffer
-        an empty string (or string shorter than 'length') may be returned!
-        """
-        return self.__data[position:(position+length)]
-  
     def read_length_coded_binary(self):
         """Read a 'Length Coded Binary' number from the data buffer.
 
@@ -163,17 +129,17 @@ class MysqlPacket(object):
         on the value of the first byte.
         """
         c = ord(self._read(1))
-        if c == NULL_COLUMN:
-            return -1
         if c < UNSIGNED_CHAR_COLUMN:
             return c
         elif c == UNSIGNED_SHORT_COLUMN:
-            return unpack_uint16(self._read(UNSIGNED_SHORT_LENGTH))
+            return unpack_uint16(self._read(2))
         elif c == UNSIGNED_INT24_COLUMN:
-            return unpack_uint24(self._read(UNSIGNED_INT24_LENGTH))
+            return unpack_uint24(self._read(3))
         elif c == UNSIGNED_INT64_COLUMN:
             # TODO: what was 'longlong'?  confirm it wasn't used?
             return -1
+        else:
+            return -1
   
     def read_length_coded_string(self):
         return self._read_length_coded_string()
@@ -200,22 +166,26 @@ class MysqlPacket(object):
         )
  
     def is_ok_packet(self):
-        return ord(self.get_bytes(0)) == 0
+        if PYTHON3:
+            return self.__data[0] == 0
+        else:
+            return self.__data[0] == b'\x00'
 
     def is_eof_packet(self):
-        return ord(self.get_bytes(0)) == 254  # 'fe'
+        if PYTHON3:
+            return self.__data[0] == 0xfe
+        else:
+            return self.__data[0] == b'\xfe'
 
-    def is_resultset_packet(self):
-        field_count = ord(self.get_bytes(0))
-        return field_count >= 1 and field_count <= 250
-  
-    def check_error(self):
-        if ord(self.get_bytes(0)) == 255:
-            self.rewind()
-            self.advance(1)  # field_count == error (we already know that)
-            errno = unpack_uint16(self._read(2))
-            return errno, self.__data
-        return 0, None
+    def is_eof_and_status(self):
+        if PYTHON3:
+            if self.__data[0] != 0xfe:
+                return False, 0, 0
+        else:
+            if self.__data[0] != b'\xfe':
+                return False, 0, 0
+
+        return True, unpack_uint16(self._read(2)), unpack_uint16(self._read(2))
 
     def read_ok_packet(self):
         self.advance(1)  # field_count (always '0')
@@ -229,7 +199,6 @@ class MysqlPacket(object):
                 server_status, warning_count, message)
 
 
-
 class FieldDescriptorPacket(MysqlPacket):
     """A MysqlPacket that represents a specific column's metadata in the result.
 
@@ -310,10 +279,7 @@ class MySQLResult(object):
         self.has_next = None
         self.has_result = False
         self.rest_rows = None
-
-    def read(self):
-        self.rest_rows = None
-        self.first_packet = read_mysqlpacket(self.connection)
+        self.first_packet = MysqlPacket(self.connection)
 
         if self.first_packet.is_ok_packet():
             (self.affected_rows, self.insert_id,
@@ -332,15 +298,15 @@ class MySQLResult(object):
             return
         rest_rows = []
         while True:
-            packet = read_mysqlpacket(self.connection)
-            if packet.is_eof_packet():
-                self.warning_count = unpack_uint16(packet.read(2))
-                server_status = unpack_uint16(packet.read(2))
+            packet = MysqlPacket(self.connection)
+            is_eof, warning_count, server_status = packet.is_eof_and_status()
+            if is_eof:
+                self.warning_count = warning_count
+                self.server_status = server_status
                 self.has_next = (server_status
                              & SERVER_STATUS.SERVER_MORE_RESULTS_EXISTS)
                 break
-            rest_rows.append(
-                packet.read_decode_data(self.fields))
+            rest_rows.append(packet.read_decode_data(self.fields))
         self.rest_rows = rest_rows
 
     def _get_descriptions(self):
@@ -348,11 +314,11 @@ class MySQLResult(object):
         self.fields = []
         description = []
         for i in range(self.field_count):
-            field = read_fielddescriptorpacket(self.connection)
+            field = FieldDescriptorPacket(self.connection)
             self.fields.append(field)
             description.append(field.description())
 
-        eof_packet = read_mysqlpacket(self.connection)
+        eof_packet = MysqlPacket(self.connection)
         assert eof_packet.is_eof_packet(), 'Protocol error, expecting EOF'
         self.description = tuple(description)
 
@@ -360,10 +326,11 @@ class MySQLResult(object):
         if not self.has_result:
             return None
         if self.rest_rows is None:
-            packet = read_mysqlpacket(self.connection)
-            if packet.is_eof_packet():
-                self.warning_count = unpack_uint16(packet.read(2))
-                server_status = unpack_uint16(packet.read(2))
+            packet = MysqlPacket(self.connection)
+            is_eof, warning_count, server_status = packet.is_eof_and_status()
+            if is_eof:
+                self.warning_count = warning_count
+                self.server_status = server_status
                 self.has_next = (server_status
                              & SERVER_STATUS.SERVER_MORE_RESULTS_EXISTS)
                 self.rest_rows = []
